@@ -57,7 +57,7 @@ public:
   XEMModelOutput(XEMModel * estimation);
   
   /// Initialization Constructor 2
-  XEMModelOutput(XEMModelType & modelType, int64_t nbCluster, vector<XEMCriterionOutput> & criterionOutput, double likelihood, XEMParameterDescription & parameterDescription, XEMLabelDescription & labelDescription,  XEMProbaDescription & probaDescription);
+  XEMModelOutput(XEMModelType & modelType, int64_t nbCluster, std::vector<XEMCriterionOutput> & criterionOutput, double likelihood, XEMParameterDescription & parameterDescription, XEMLabelDescription & labelDescription,  XEMProbaDescription & probaDescription);
   
   ///Initialization Constructor 3
   XEMModelOutput(XEMModelType & modelType, int64_t nbCluster, XEMErrorType error);
